@@ -1,4 +1,5 @@
-coefficients.evmOpt <-
+#' @export
+coef.evmOpt <-
 function(object, ...){
     res <- object$coefficients
 #    if (length(res) == 2)
@@ -6,8 +7,3 @@ function(object, ...){
     res
 }
 
-coef.evmOpt <- coefficients.evmOpt
-#function(object, ...) {
-#  coefficients.evm(object)
-#}
-
