@@ -1,4 +1,5 @@
-coefficients.migpd <-
+#' @export
+coef.migpd <-
 function(object, ...){
     co <- sapply(object$models, function(x) x$coefficients)
     up <- sapply(object$models, function(x) endPoint(x,verbose=FALSE))
@@ -9,6 +10,4 @@ function(object, ...){
     co
 }
 
-coef.migpd <- coefficients.migpd
-
 
