@@ -1,3 +1,4 @@
+#' @export
 `print.mexDependence` <-
 function(x, ...){
     cat("Conditioning on ", x$conditioningVariable, " variable.", sep="")
@@ -5,7 +6,7 @@ function(x, ...){
 
     cat("\nThresholding quantiles for transformed data: dqu = ", x$dqu, sep="")
 
-    cat("\nUsing ",x$margins," margins for dependence estimation.", sep="")
+    cat("\nUsing ",x$margins[[1]]," margins for dependence estimation.", sep="")
     if(x$constrain){
         cat("\nConstrained estimation of dependence parameters using v =",x$v,".")
     }
@@ -14,10 +15,10 @@ function(x, ...){
   
     cat("\nDependence structure parameter estimates:\n")
     if (!all(is.na(x$coefficients[3:4,])) & any(abs(x$coefficients)[3:4, ] > 10^(-6),na.rm=TRUE)){
-        print(x$coefficients[1:4,], ...)
+        print(signif(x$coefficients[1:4,],4), ...)
     }
     else {
-        print(x$coefficients[1:2, ], ...)
+        print(signif(x$coefficients[1:2, ],4), ...)
     }
     invisible()
-}
\ No newline at end of file
+}
