@@ -1,3 +1,5 @@
+#' @rdname mex
+#' @export
 summary.predict.mex <- function( object, mth, probs=c( .05, .5, .95 ), ... ){
     if ( is.R() ) stdev <- function( x ) sqrt( var( x ) )
     if ( missing( mth ) ) mth <- object$mth
@@ -61,6 +63,7 @@ summary.predict.mex <- function( object, mth, probs=c( .05, .5, .95 ), ... ){
     ans
 }
 
+#' @export
 print.summary.predict.mex <- function( x, ... ){
     print( x$call, ... )
 
@@ -74,5 +77,5 @@ print.summary.predict.mex <- function( x, ... ){
 
     print( signif(x$thres,3), ... )
 
-    invisible()
-}
\ No newline at end of file
+    invisible(x)
+}
